@@ -422,7 +422,8 @@ class ObjectPropertyClass(ReasoningPropertyClass):
   def __init__(Prop, name, bases, obj_dict):
     super().__init__(name, bases, obj_dict)
     
-    if issubclass_python(Prop, SymmetricProperty):
+    #if issubclass_python(Prop, SymmetricProperty):
+    if SymmetricProperty in Prop.is_a:
       type.__setattr__(Prop, "_inverse_storid", Prop.storid)
       Prop._inverse_property = Prop
       
